Crate rdocx_html

Crate rdocx_html 

rdocx-html

rdocx-html converts parsed Word content to a complete HTML document, an HTML fragment, or Markdown. It works from semantic WordprocessingML and does not run the page layout engine. Use the high-level rdocx facade when starting from a DOCX file.

use rdocx_html::{HtmlInput, HtmlOptions, to_html_document, to_markdown};

fn export(input: &HtmlInput) -> (String, String) {
    (
        to_html_document(input, &HtmlOptions::default()),
        to_markdown(input),
    )
}
[dependencies]
rdocx-html = "0.5"

Structs

HtmlInput
Input for HTML conversion.
HtmlOptions
Options for HTML conversion.
ImageData
Image data for HTML embedding.

Functions

to_html_document
Convert a DOCX document to a complete HTML document string.
to_html_fragment
Convert a DOCX document to an HTML fragment (body content only).
to_markdown
Convert a DOCX document to Markdown.